@@ -1,14 +1,14 @@
 package Complete::Dist::Zilla;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-09-09'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 #use Log::Any '$log';
 
-use Complete;
+use Complete::Setting;
 
 our %SPEC;
 require Exporter;
@@ -51,9 +51,9 @@ sub complete_dzil_plugin {
     my %args = @_;
 
     my $word = $args{word} // '';
-    my $ci          = $args{ci} // $Complete::OPT_CI;
-    my $map_case    = $args{map_case} // $Complete::OPT_MAP_CASE;
-    my $exp_im_path = $args{exp_im_path} // $Complete::OPT_EXP_IM_PATH;
+    my $ci          = $args{ci} // $Complete::Setting::OPT_CI;
+    my $map_case    = $args{map_case} // $Complete::Setting::OPT_MAP_CASE;
+    my $exp_im_path = $args{exp_im_path} // $Complete::Setting::OPT_EXP_IM_PATH;
 
     Complete::Module::complete_module(
         word => $word,
@@ -76,9 +76,9 @@ sub complete_dzil_role {
     my %args = @_;
 
     my $word = $args{word} // '';
-    my $ci          = $args{ci} // $Complete::OPT_CI;
-    my $map_case    = $args{map_case} // $Complete::OPT_MAP_CASE;
-    my $exp_im_path = $args{exp_im_path} // $Complete::OPT_EXP_IM_PATH;
+    my $ci          = $args{ci} // $Complete::Setting::OPT_CI;
+    my $map_case    = $args{map_case} // $Complete::Setting::OPT_MAP_CASE;
+    my $exp_im_path = $args{exp_im_path} // $Complete::Setting::OPT_EXP_IM_PATH;
 
     Complete::Module::complete_module(
         word => $word,
@@ -101,9 +101,9 @@ sub complete_dzil_bundle {
     my %args = @_;
 
     my $word = $args{word} // '';
-    my $ci          = $args{ci} // $Complete::OPT_CI;
-    my $map_case    = $args{map_case} // $Complete::OPT_MAP_CASE;
-    my $exp_im_path = $args{exp_im_path} // $Complete::OPT_EXP_IM_PATH;
+    my $ci          = $args{ci} // $Complete::Setting::OPT_CI;
+    my $map_case    = $args{map_case} // $Complete::Setting::OPT_MAP_CASE;
+    my $exp_im_path = $args{exp_im_path} // $Complete::Setting::OPT_EXP_IM_PATH;
 
     Complete::Module::complete_module(
         word => $word,
@@ -127,7 +127,7 @@ Complete::Dist::Zilla - Complete with installed Dist::Zilla plugin names
 
 =head1 VERSION
 
-This document describes version 0.04 of Complete::Dist::Zilla (from Perl distribution Complete-Dist-Zilla), released on 2015-09-03.
+This document describes version 0.05 of Complete::Dist::Zilla (from Perl distribution Complete-Dist-Zilla), released on 2015-09-09.
 
 =head1 SYNOPSIS
 
